@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "bvh_intersector_hybrid.h"
 #include "bvh_traverser1.h"
@@ -453,7 +440,7 @@ namespace embree
             /* process nodes */
             //STAT3(normal.trav_nodes, 1, popcnt(valid_node), K);
             const NodeRef nodeRef = cur;
-            const AlignedNode* __restrict__ const node = nodeRef.alignedNode();
+            const AABBNode* __restrict__ const node = nodeRef.getAABBNode();
 
             vfloat<Nx> fmin;
             size_t m_frustum_node = intersectNodeFrustum<N,Nx>(node, frustum, fmin);
@@ -477,7 +464,7 @@ namespace embree
               {                                
                 const vfloat<K> childDist = fmin[i];
                 const NodeRef child = node->child(i);
-                child.prefetch();
+                BVHN<N>::prefetch(child);
                 if (any(childDist < curDist))
                 {
                   if (likely(cur != BVH::emptyNode)) {
@@ -864,7 +851,7 @@ namespace embree
             /* process nodes */
             //STAT3(normal.trav_nodes, 1, popcnt(valid_node), K);
             const NodeRef nodeRef = cur;
-            const AlignedNode* __restrict__ const node = nodeRef.alignedNode();
+            const AABBNode* __restrict__ const node = nodeRef.getAABBNode();
 
             vfloat<Nx> fmin;
             size_t m_frustum_node = intersectNodeFrustum<N,Nx>(node, frustum, fmin);
@@ -888,7 +875,7 @@ namespace embree
               {                                
                 const NodeRef child = node->child(i);
                 assert(child != BVH::emptyNode);
-                child.prefetch();
+                BVHN<N>::prefetch(child);
                 if (likely(cur != BVH::emptyNode)) {
                   num_child_hits++;
                   stackPtr->ptr  = cur;
